﻿using System;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Drawing;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.Styles;
using ThinkGeo.MapSuite.WebForms;
using System.Collections.ObjectModel;

//MapPath(@"App_Data\states.shp")

namespace _9272
{
    public partial class WebForm1 : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                // Set the Map Unit. The reason for setting it to DecimalDegrees is that is what the shapefile’s unit of measure is inherently in.
                Map1.MapUnit = GeographyUnit.Meter;

                LoadData();
            }
        }

        private void LoadData()
        {
            //RP Layer 
            ShapeFileFeatureLayer RPLayer = new ShapeFileFeatureLayer(MapPath(@"App_Data\RP_ROAD.shp"));
            RPLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            ShapeFileFeatureLayer GutBOLayer = new ShapeFileFeatureLayer(MapPath(@"App_Data\GUT_BO_BAVDHAN_BK.shp"));
            GutBOLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.CreateSimpleTextStyle("ID,TEXTSTRING", "Arial", 10, DrawingFontStyles.Bold, GeoColor.StandardColors.Transparent, 0, 0);
            GutBOLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay staticOverlay = new LayerOverlay();
            staticOverlay.Layers.Add("RPFile", RPLayer);
            staticOverlay.Layers.Add("GOFile", GutBOLayer);

            Map1.CustomOverlays.Add(staticOverlay);
            RPLayer.Open();
            Map1.CurrentExtent = RPLayer.GetBoundingBox();
            AreaStyle areast = new AreaStyle();
            areast.OutlinePen.Color = GeoColor.StandardColors.Black;
            AreaStyle areastrp = new AreaStyle();
            areastrp.OutlinePen.Color = GeoColor.StandardColors.Red;
            areastrp.OutlinePen.Width = 3;
            GutBOLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(areast);
            RPLayer.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(areastrp);
        }

        protected void Map1_Click(object sender, MapClickedEventArgs e)
        {
            Collection<Feature> finalFeature = new Collection<Feature>();
            ValueStyle valueSchema = new ValueStyle();
            valueSchema.ColumnName = "TEXTSTRING";
            ValueStyle RoadvalueSchema = new ValueStyle();
            RoadvalueSchema.ColumnName = "ID";
            RectangleShape rshp = new RectangleShape();
            ShapeFileFeatureLayer RPLayerShape = (ShapeFileFeatureLayer)((LayerOverlay)Map1.CustomOverlays[0]).Layers["RPFile"];
            ShapeFileFeatureLayer GOLayerShape = (ShapeFileFeatureLayer)((LayerOverlay)Map1.CustomOverlays[0]).Layers["GOFile"];
            GOLayerShape.Open();
            RPLayerShape.Open();


            Collection<Feature> GOintersectFeature = GOLayerShape.QueryTools.GetFeaturesIntersecting(e.Position, new string[3] { "ID", "TEXTSTRING", "AREA" });
            Collection<Feature> intersectFeature = RPLayerShape.QueryTools.GetFeaturesIntersecting(e.Position, new string[3] { "ID", "STRING", "AREA1" });

            Feature result = GOintersectFeature[0].GetIntersection(intersectFeature[0]);


            GOLayerShape.Close();
            RPLayerShape.Close();
            InMemoryFeatureLayer inMemory = new InMemoryFeatureLayer();
            inMemory.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = new AreaStyle(new GeoSolidBrush(GeoColor.SimpleColors.Green));
            inMemory.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            LayerOverlay dynamicOverlay = new LayerOverlay();
            dynamicOverlay.Layers.Add("InMemoryF", inMemory);
            dynamicOverlay.TileType = TileType.SingleTile;
            dynamicOverlay.IsBaseOverlay = false;

            inMemory.InternalFeatures.Clear();
            inMemory.InternalFeatures.Add(result);



            RPLayerShape.ZoomLevelSet.ZoomLevel01.CustomStyles.Add(RoadvalueSchema);
            Map1.CustomOverlays.Add(dynamicOverlay);
            dynamicOverlay.Redraw();
        }
    }
}